Module tty

Module tty 

Functions

is_interactive
Returns true when stdin is connected to a terminal (i.e. the process is running interactively), false otherwise (e.g. stdin is a pipe or redirected file, which is the common case in CI environments).