Functions
- is_
interactive - Returns
truewhen stdin is connected to a terminal (i.e. the process is running interactively),falseotherwise (e.g. stdin is a pipe or redirected file, which is the common case in CI environments).
true when stdin is connected to a terminal (i.e. the process is
running interactively), false otherwise (e.g. stdin is a pipe or
redirected file, which is the common case in CI environments).